cumulusci.tasks.preflight package
=================================

.. automodule:: cumulusci.tasks.preflight
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.tasks.preflight.licenses module
-----------------------------------------

.. automodule:: cumulusci.tasks.preflight.licenses
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.preflight.packages module
-----------------------------------------

.. automodule:: cumulusci.tasks.preflight.packages
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.preflight.settings module
-----------------------------------------

.. automodule:: cumulusci.tasks.preflight.settings
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.preflight.sobjects module
-----------------------------------------

.. automodule:: cumulusci.tasks.preflight.sobjects
   :members:
   :undoc-members:
   :show-inheritance:
